From 9bc838b71b84febb5e3a8d846a210c99fe4c2128 Mon Sep 17 00:00:00 2001
From: Li-Heng Chen <lihengc@netflix.com>
Date: Fri, 9 Sep 2022 10:53:20 -0700
Subject: [PATCH] fftools/ffmpeg: Fix EOF pts for libavfilter in
 send_filter_eof()

When input is video bitstream (e.g. *.264) with framerate set by
-r, ist->pts could be a nonsense value.

In libavfilter/vf_fps, the pts value of EOF from above is compared
to pts derived from inlink. The wrong EOF pts may trigger a bug,
where ffmpeg keeps writting the last video frame to the output.
This bug can be easily reproduced by the ffmpeg cmd below
(h264 bitstreams in fate-suite can reproduce this issue):

ffmpeg -r 24/1 -i fate-suite/h264/bbc2.sample.h264 -vf fps=24/1 -f rawvideo out.yuv

Signed-off-by: Li-Heng Chen <lihengc@netflix.com>
---
 fftools/ffmpeg.c | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/fftools/ffmpeg.c b/fftools/ffmpeg.c
index 0e1477299d..ea66c9c706 100644
--- a/fftools/ffmpeg.c
+++ b/fftools/ffmpeg.c
@@ -2383,6 +2383,9 @@ static int send_filter_eof(InputStream *ist)
     int64_t pts = av_rescale_q_rnd(ist->pts, AV_TIME_BASE_Q, ist->st->time_base,
                                    AV_ROUND_NEAR_INF | AV_ROUND_PASS_MINMAX);
 
+    if (ist->framerate.num)
+        pts = ist->cfr_next_pts;
+
     for (i = 0; i < ist->nb_filters; i++) {
         ret = ifilter_send_eof(ist->filters[i], pts);
         if (ret < 0)
-- 
2.32.1 (Apple Git-133)

